@@ -7,21 +7,30 @@ from dots import token
 class Invoice():
 
     @classmethod
-    def create(cls, amount, expires_in, items, breakdown, requested_information):
+    def create(cls, amount, expires_in=None, items=None, breakdown=None, requested_information=None):
         
         json = {
             'amount': amount,
-            'expires_in': expires_in,
-            'items': items,
-            'breakdown': breakdown,
-            'requested_information': requested_information,
         }
 
+        if expires_in is not None:
+            json['expires_in'] = expires_in
+        
+        if items is not None:
+            json['items'] = items
+        
+        if breakdown is not None:
+            json['breakdown'] = breakdown
+        
+        if requested_information is not None:
+            json['requested_information'] = requested_information
+
         headers = {
             'Authorization': 'Basic ' + token.get_auth_token()
         }
 
         response = requests.post(dots.api_base + '/invoice/create', json=json, headers=headers)
+        print(response.text)
         data = response.json()
 
         if data['success']:
